@@ -11,6 +11,11 @@
 #' \eqn{C_{plasma} = \frac{C_{blood}}{R_{b2p}}} for a tissue independent value of 
 #' \eqn{R_{b2p}}.
 #' 
+#' Model Figure 
+#' \if{html}{\figure{1comp.png}{options: width="60\%" alt="Figure: One
+#' Compartment Model Schematic"}}
+#' \if{latex}{\figure{1comp.pdf}{options: width=12cm alt="Figure: One
+#' Compartment Model Schematic"}}
 #' Note that the timescales for the model parameters have units of hours while 
 #' the model output is in days.
 #' 
@@ -20,71 +25,112 @@
 #' appropriate physiological data(volumes and flows) but substitutes human
 #' fraction unbound, partition coefficients, and intrinsic hepatic clearance.
 #' 
-#' AUC is area under plasma concentration curve.
-#' 
-#' Model Figure 
-#' \if{html}{\figure{1comp.png}{options: width="60\%" alt="Figure: One
-#' Compartment Model Schematic"}}
-#' \if{latex}{\figure{1comp.pdf}{options: width=12cm alt="Figure: One
-#' Compartment Model Schematic"}}
+#' Because this model does not simulate exhalation, inhalation, and other 
+#' processes relevant to volatile chemicals, this model is by default 
+#' restricted to chemicals with a logHenry's Law Constant less than that of 
+#' Acetone, a known volatile chemical. That is, chemicals with logHLC > -4.5 
+#' (Log10 atm-m3/mole) are excluded. Volatility is not purely determined by the 
+#' Henry's Law Constant, therefore this chemical exclusion may be turned off 
+#' with the argument "physchem.exclude = FALSE". Similarly, per- and 
+#' polyfluoroalkyl substances (PFAS) are excluded by default because the 
+#' transporters that often drive PFAS toxicokinetics are not included in this 
+#' model. However, PFAS chemicals can be included with the argument 
+#' "class.exclude = FALSE".
 #' 
 #' @param chem.name Either the chemical name, CAS number, or the parameters
 #' must be specified.
+#' 
 #' @param chem.cas Either the chemical name, CAS number, or the parameters must
 #' be specified.
+#' 
 #' @param dtxsid EPA's 'DSSTox Structure ID (\url{https://comptox.epa.gov/dashboard})  
 #' the chemical must be identified by either CAS, name, or DTXSIDs
+#' 
 #' @param times Optional time sequence for specified number of days.
+#' 
 #' @param parameters Chemical parameters from parameterize_1comp function,
 #' overrides chem.name and chem.cas.
+#' 
 #' @param days Length of the simulation.
+#' 
 #' @param tsteps The number time steps per hour.
+#' 
 #' @param daily.dose Total daily dose, default is mg/kg BW.
+#' 
 #' @param dose Amount of a single dose, default is mg/kg BW. 
+#' 
 #' @param doses.per.day Number of doses per day.
+#' 
 #' @param species Species desired (either "Rat", "Rabbit", "Dog", or default
 #' "Human").
+#' 
 #' @param iv.dose Simulates a single i.v. dose if true.
+#' 
 #' @param input.units Input units of interest assigned to dosing, defaults to
 #' "mg/kg" BW. 
+#' 
 #' @param output.units A named vector of output units expected for the model
 #' results. Default, NULL, returns model results in units specified in the
 #' 'modelinfo' file. See table below for details.
+#' 
 #' @param initial.values Vector containing the initial concentrations or
 #' amounts of the chemical in specified tissues with units corresponding to
 #' output.units.  Defaults are zero.
+#' 
 #' @param suppress.messages Whether or not the output message is suppressed.
+#' 
 #' @param plots Plots all outputs if true.
+#' 
 #' @param default.to.human Substitutes missing rat values with human values if
 #' true.
+#' 
+#' @param class.exclude Exclude chemical classes identified as outside of 
+#' domain of applicability by relevant modelinfo_[MODEL] file (default TRUE).
+#' 
+#' @param physchem.exclude Exclude chemicals on the basis of physico-chemical
+#' properties (currently only Henry's law constant) as specified by 
+#' the relevant modelinfo_[MODEL] file (default TRUE).
+#' 
 #' @param dosing.matrix Vector of dosing times or a matrix consisting of two
 #' columns or rows named "dose" and "time" containing the time and amount, in
 #' mg/kg BW by default, of each dose.
+#' 
 #' @param recalc.clearance Whether or not to recalculate the elimination
 #' rate.
+#' 
 #' @param recalc.blood2plasma Whether or not to recalculate the blood:plasma
 #' chemical concentrationr ratio
+#' 
 #' @param adjusted.Funbound.plasma Uses adjusted Funbound.plasma when set to
 #' TRUE along with volume of distribution calculated with this value.
+#' 
 #' @param regression Whether or not to use the regressions in calculating
 #' partition coefficients in volume of distribution calculation.
+#' 
 #' @param restrictive.clearance In calculating elimination rate, protein
 #' binding is not taken into account (set to 1) in liver clearance if FALSE.
+#' 
 #' @param minimum.Funbound.plasma Monte Carlo draws less than this value are set 
 #' equal to this value (default is 0.0001 -- half the lowest measured Fup in our
 #' dataset).
-#' @param Caco2.options A list of options to use when working with Caco2 apical to
-#' basolateral data \code{Caco2.Pab}, default is Caco2.options = list(Caco2.Pab.default = 1.6,
-#' Caco2.Fabs = TRUE, Caco2.Fgut = TRUE, overwrite.invivo = FALSE, keepit100 = FALSE). Caco2.Pab.default sets the default value for 
-#' Caco2.Pab if Caco2.Pab is unavailable. Caco2.Fabs = TRUE uses Caco2.Pab to calculate
-#' fabs.oral, otherwise fabs.oral = \code{Fabs}. Caco2.Fgut = TRUE uses Caco2.Pab to calculate 
-#' fgut.oral, otherwise fgut.oral = \code{Fgut}. overwrite.invivo = TRUE overwrites Fabs and Fgut in vivo values from literature with 
-#' Caco2 derived values if available. keepit100 = TRUE overwrites Fabs and Fgut with 1 (i.e. 100 percent) regardless of other settings.
+#' 
+#' @param Caco2.options A list of options to use when working with Caco2 apical 
+#' to basolateral data \code{Caco2.Pab}, default is Caco2.options = 
+#' list(Caco2.Pab.default = 1.6, Caco2.Fabs = TRUE, Caco2.Fgut = TRUE, 
+#' overwrite.invivo = FALSE, keepit100 = FALSE). Caco2.Pab.default sets the 
+#' default value for Caco2.Pab if Caco2.Pab is unavailable. Caco2.Fabs = TRUE 
+#' uses Caco2.Pab to calculate fabs.oral, otherwise fabs.oral = \code{Fabs}. 
+#' Caco2.Fgut = TRUE uses Caco2.Pab to calculate 
+#' fgut.oral, otherwise fgut.oral = \code{Fgut}. overwrite.invivo = TRUE 
+#' overwrites Fabs and Fgut in vivo values from literature with 
+#' Caco2 derived values if available. keepit100 = TRUE overwrites Fabs and Fgut 
+#' with 1 (i.e. 100 percent) regardless of other settings.
 #' See \code{\link{get_fbio}} for further details.
 #' 
 #' @param monitor.vars Which variables are returned as a function of time. 
 #' Defaults value of NULL provides "Agutlumen", "Ccompartment", "Ametabolized",
 #' "AUC"
+#' 
 #' @param ... Additional arguments passed to the integrator (deSolve).
 #'
 #' @return A matrix with a column for time(in days) and a column for the
@@ -119,6 +165,13 @@
 #' 
 #' solve_1comp(chem.name="Besonprodil", daily.dose=1, dose=NULL,
 #'             days=2.5, doses.per.day=4)
+#' 
+#' # The following will not work because Diquat dibromide monohydrate's 
+#' # Henry's Law Constant (-3.912) is higher than that of Acetone (~-4.5):
+#' try(head(solve_1comp(chem.cas = "6385-62-2")))
+#' # However, we can turn off checking for phys-chem properties, since we know
+#' # that  Diquat dibromide monohydrate is not too volatile:
+#' head(solve_1comp(chem.cas = "6385-62-2", physchem.exclude = FALSE))
 #' }
 #'
 #' @seealso \code{\link{solve_model}}
@@ -147,6 +200,8 @@ solve_1comp <- function(chem.name = NULL,
                     # output.units='uM',
                     output.units=NULL,
                     default.to.human=FALSE,
+                    class.exclude = TRUE,
+                    physchem.exclude = TRUE,
                     recalc.blood2plasma=FALSE,
                     recalc.clearance=FALSE,
                     dosing.matrix=NULL,
@@ -185,12 +240,14 @@ solve_1comp <- function(chem.name = NULL,
     recalc.clearance=recalc.clearance,
     adjusted.Funbound.plasma=adjusted.Funbound.plasma,
     minimum.Funbound.plasma=minimum.Funbound.plasma,
-    parameterize.arg.list=list(
+    parameterize.args.list =list(
                       default.to.human=default.to.human,
                       clint.pvalue.threshold=0.05,
                       restrictive.clearance = restrictive.clearance,
                       regression=regression,
-                      Caco2.options=Caco2.options),
+                      Caco2.options=Caco2.options,
+                      class.exclude = class.exclude,
+                      physchem.exclude = physchem.exclude),
     ...)
   
   return(out) 
